; docformat = 'rst'
;+
; This is an example program to demonstrate how to create additional Y axes for a plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;
; :Examples:
;    Save the program as "additional_axes_plot.pro" and run it like this::
;       IDL> .RUN additional_axes_plot
;
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 26 July 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Additional_Axes_Plot

    ; Create some data.
    data_1 = cgScaleVector(cgDemodata(17), 0.0, 1.0)
    data_2 = cgScaleVector(cgDemodata(17), 0.0, 1000.0)
    data_3 = (Findgen(101)+1) / 5
    
    thick = (!D.Name EQ 'PS') ? 6 : 2
    
    ; Open a window and draw the plot without either of the Y axes.
    cgDisplay, 600, 450
    cgPlot, data_1, YStyle=4, Position=[0.15, 0.15, 0.7, 0.820], /NoData
    
    ; Draw the first Y axis in red.
    cgAxis, YAxis=0.0, /Save, Color='red7', YTitle='Data 1'
    cgOPlot, data_1, Color='red7', Thick=thick
    
    ; Draw the second Y axis in green.
    cgAxis, YAxis=1.0, /Save, Color='grn7', YTitle='Data 2', YRange=[0,1000]
    cgOPlot, data_2, Color='grn7', LineStyle=2, Thick=thick
    
    ; Draw the third Y axis in blue.
    cgAxis, 0.85, 0.15, /Normal, YAxis=1.0, /Save, Color='blu7', YTitle='Data 3', YRange=[0.1,100], /YLog
    cgOPlot, data_3, Color='blu7', LineStyle=1, Thick=thick
        
       
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Additional_Axes_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Additional_Axes_Plot', WTitle='Additional Axes Plot in Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'additional_axes_plot.ps', FONT=1
  Additional_Axes_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'additional_axes_plot.ps', /PNG, WIDTH=600

END